@@ -9,12 +9,13 @@ check_model_set_validity <- function(object) {
 .ModelSet <- setClass(
   "ModelSet",
   slots = c(
-    response_unit = "list",
-    covariate_units = "list",
+    response = "list",
+    covariates = "list",
     predict_fn = "function",
     descriptors = "tbl_df",
     pub_descriptors = "tbl_df",
     models = "list",
+    response_definition = "character",
     covariate_definitions = "list"
   ),
   validity = check_model_set_validity
@@ -28,16 +29,20 @@ check_model_set_validity <- function(object) {
 #' @return An instance of a ModelSet
 #' @export
 #' @keywords internal
-ModelSet <- function(response_unit, covariate_units, predict_fn,
-                     descriptors = list(), covariate_definitions = list()) {
-  descriptors <- tibble::as_tibble(descriptors)
+ModelSet <- function(response, covariates, predict_fn,
+                     descriptors = list(),
+                     response_definition = NA_character_,
+                     covariate_definitions = list()) {
+  
+  descriptors <- descriptors_to_tibble_row(descriptors)
 
   model_set <- .ModelSet(
-    response_unit = response_unit,
-    covariate_units = covariate_units,
+    response = response,
+    covariates = covariates,
     predict_fn = predict_fn,
     descriptors = descriptors,
     pub_descriptors = tibble::tibble(),
+    response_definition = response_definition,
     covariate_definitions = covariate_definitions
   )
 
