@@ -105,7 +105,7 @@ test_that("merging with model_tbl returns model_tbl", {
 })
 
 
-test_that("expand_taxa correctly expands the taxa column", {
+test_that("unnest_taxa correctly expands the taxa column", {
   test_model_tbl_one <- new_model_tbl(
     tibble::tibble(model = c(fixed_effects_model), dsob = 1, class = "a")
   )
@@ -142,4 +142,4 @@ test_that("expand_taxa correctly expands the taxa column", {
   expanded_two <- test_model_tbl_two %>% unnest_taxa()
 
   expect_true(nrow(expanded_two) == 4)
-})
+})
\ No newline at end of file
