@@ -1,6 +1,6 @@
 param_mod <- ParametricModel(
-  response_unit = list(vsia = units::as_units("ft^3")),
-  covariate_units = list(dsob = units::as_units("in")),
+  response = list(vsia = units::as_units("ft^3")),
+  covariates = list(dsob = units::as_units("in")),
   predict_fn = function(dsob) {
     dsob * a
   },
