@@ -1,8 +1,8 @@
 parametric_set <- ParametricSet(
-  response_unit = list(
+  response = list(
     "vsia" = units::as_units("ft^3")
   ),
-  covariate_units = list(
+  covariates = list(
     "dsob" = units::as_units("in")
   ),
   parameter_names = "a",
